pub struct HellmanOutput(/* private fields */);Expand description
Helper for the following requirements for output:
- Any stdout output line with a required result must have OUTPUT as the first word (token).
- All numerical values required by an assignment must have whitespace (which includes end of line) around them.
- Required textual output should be surrounded by single colons (:).
- The order for results is assignment specific and important, they must emanate from the application in the order dictated by the assignment.
Implementations
Sourceimpl HellmanOutput
impl HellmanOutput